robotpy-playingwithfusion
=========================

This is a python wrapper around the Playing With Fusion device support library.
The RobotPy project is not associated with or endorsed by Playing With Fusion Inc.

We don't own any PWF hardware, so these may have some issues. Please try them out
and let us know how it goes!

Documentation
=============

* `Installation <http://robotpy.readthedocs.io/en/stable/install/pwfusion.html>`_
* `Python API Documentation <http://robotpy.readthedocs.io/projects/pwfusion/en/stable/api.html>`_


License
=======

RobotPy specific bits are available under the Apache 2.0 license.

Author
======

Dustin Spicuzza (dustin@virtualroadside.com)
